@@ -1,49 +1,66 @@
 forest.orbbound <- function(x,
-                            comb.fixed=x$meta$comb.fixed,
-                            comb.random=x$meta$comb.random,
+                            comb.fixed=x$x$comb.fixed,
+                            comb.random=x$x$comb.random,
                             text.fixed="FE model",
                             text.random="RE model",
                             smlab=NULL,
                             leftcols=c("studlab", "maxbias"),
                             leftlabs=c("Missing\nstudies", "Maximum\nbias"),
-                            logscale=FALSE,
+                            backtransf=x$backtransf,
                             digits=max(3, .Options$digits - 3),
                             ...){
 
   if (!inherits(x, "orbbound"))
     stop("Argument 'x' must be an object of class \"orbbound\"")
   
-  k <- x$meta$k
-  sm <- x$meta$sm
+  k <- x$x$k
+  sm <- x$x$sm
+  
+  
+  cl <- class(x)[1]
+  addargs <- names(list(...))
+  ##
+  fun <- "print.summary.limitmeta"
+  ##
+  meta:::warnarg("logscale", addargs, fun, otherarg="backtransf")
+  ##
+  if (is.null(backtransf))
+    if (!is.null(list(...)[["logscale"]]))
+      backtransf <- !list(...)[["logscale"]]
+    else
+      backtransf <- TRUE
+  
   
   if (length(comb.fixed)==0)
     comb.fixed <- TRUE
   ##
   if (length(comb.random)==0)
     comb.random <- TRUE
+  
+  
+  sm.lab <- sm
   ##
-  if (length(logscale)==0)
-    logscale <- FALSE
+  if (backtransf){
+    if (sm=="ZCOR")
+      sm.lab <- "COR"
+    if (sm %in% c("PFT", "PAS", "PRAW", "PLOGIT", "PLN"))
+      sm.lab <- "proportion"
+  }
+  else 
+    if (meta:::is.relative.effect(sm))
+      sm.lab <- paste("log", sm, sep="")
   
-  if (sm=="ZCOR")
-    sm.lab <- "COR"
-  else if (sm %in% c("PFT", "PAS", "PRAW", "PLOGIT"))
-    sm.lab <- "proportion"
-  else if (!logscale & sm == "PLN")
-    sm.lab <- "proportion"
-  else if (logscale & (sm == "RR" | sm == "OR" | sm == "HR"))
-    sm.lab <- paste("log", sm, sep="")
-  else
-    sm.lab <- sm
   
-  ci.lab <- paste(round(100*x$meta$level.comb, 1), "%-CI", sep="")
+  ci.lab <- paste(round(100*x$x$level.comb, 1), "%-CI", sep="")
+  
   
   TE.fixed   <- x$fixed$TE
   seTE.fixed <- rep(x$fixed$seTE, length(TE.fixed))
   ##
   TE.random   <- x$random$TE
   seTE.random <- rep(x$random$seTE, length(TE.random))
-
+  
+  
   if (comb.fixed & comb.random){
     TE <- c(TE.fixed, TE.random)
     seTE <- c(seTE.fixed, seTE.random)
@@ -66,7 +83,8 @@ forest.orbbound <- function(x,
     warning("No forest plot generated as both arguments 'comb.fixed' and 'comb.random' are FALSE")
     return(invisible(NULL))
   }
-
+  
+  
   if (comb.fixed & comb.random)
     m1 <- metagen(TE, seTE, sm=sm.lab,
                   byvar=FEvsRE, print.byvar=FALSE,
@@ -77,16 +95,20 @@ forest.orbbound <- function(x,
   if (comb.fixed & comb.random){
     m1$studlab <- c(x$k.suspect, x$k.suspect)
     m1$maxbias <- c(x$maxbias, x$maxbias)
+    m1$npft.ma <- c(1/mean(1/x$x$n), 1/mean(1/x$x$n))
   }
   else{
     m1$studlab <- x$k.suspect
     m1$maxbias <- x$maxbias
+    m1$npft.ma <- 1/mean(1/x$x$n)
   }
-
-  if (!logscale & (sm == "RR" | sm == "OR" | sm == "HR" | sm=="PLN"))
-    m1$maxbias <- format(round(exp(m1$maxbias), digits))
-  else
-    m1$maxbias <- format(round(m1$maxbias, digits))
+  
+  
+  if (backtransf)
+    m1$maxbias <- meta:::backtransf(m1$maxbias, sm, "mean",
+                                    m1$npft.ma, warn=FALSE)
+  ##
+  m1$maxbias <- format(round(m1$maxbias, digits))
   
   forest(m1,
          comb.fixed=FALSE, comb.random=FALSE,
@@ -98,5 +120,6 @@ forest.orbbound <- function(x,
          weight="same",
          ...)
   
+  
   invisible(NULL)
 }
